==> ejc-law-impl-3.0.0-20221026.081256-14-sources.jar: com/ejianc/business/law/controller/CasePaymentController.java <==
package com.ejianc.business.law.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.law.bean.CasePaymentZiEntity;
import com.ejianc.business.law.bean.CaseRegisteEntity;
import com.ejianc.business.law.service.impl.CasePaymentZiBpmServiceImpl;
import com.ejianc.business.law.service.impl.CasePaymentZiServiceImpl;
import com.ejianc.business.law.service.impl.CaseRegisteServiceImpl;
import com.ejianc.business.law.vo.CasePaymentZiVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.law.bean.CasePaymentEntity;
import com.ejianc.business.law.service.ICasePaymentService;
import com.ejianc.business.law.vo.CasePaymentVO;

/**
 * 案件付款情况登记表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("casePayment")
public class CasePaymentController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ICasePaymentService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private CaseRegisteServiceImpl registeService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<CasePaymentVO> saveOrUpdate(@RequestBody CasePaymentVO saveOrUpdateVO) {
    	CasePaymentEntity entity = BeanMapper.map(saveOrUpdateVO, CasePaymentEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
//                entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }
//        /**
//         * 更新主表中子表应付总金额和未付总金额
//         */
//        List<CasePaymentZiVO> ziVOList = saveOrUpdateVO.getCasePaymentZiList();
//        System.out.println(ziVOList);
//        //应付总金额
//        BigDecimal totalPayable = BigDecimal.ZERO;
//        //未付总金额
//        BigDecimal totalUnpaid = BigDecimal.ZERO;
//        for (CasePaymentZiVO ziVO : ziVOList) {
//            //子表应付金额
//            BigDecimal payable = ziVO.getAmountPayable();
//            //子表未付金额
//            BigDecimal unpaid = ziVO.getAmountUnpaid();
//            if(payable == null){
//                totalPayable = totalPayable.add(BigDecimal.ZERO);
//            } else {
//                totalPayable = totalPayable.add(payable);
//            }
//            if(unpaid == null){
//                totalUnpaid = totalUnpaid.add(BigDecimal.ZERO);
//            } else {
//                totalUnpaid = totalUnpaid.add(unpaid);
//            }
//        }
//    	entity.setTotalAmountPayable(totalPayable);
//        entity.setTotalAmountUnpaid(totalUnpaid);
//        /**
//         *结束
//         */
        service.saveOrUpdate(entity, false);

        //更改支付状态
        registeService.update(Wrappers.<CaseRegisteEntity>lambdaUpdate()
                        .set(CaseRegisteEntity::getPayStateName,saveOrUpdateVO.getPayStateName())
                        .eq(CaseRegisteEntity::getId,saveOrUpdateVO.getCaseId()));
    	CasePaymentVO vo = BeanMapper.map(entity, CasePaymentVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CasePaymentVO> queryDetail(Long id) {
    	CasePaymentEntity entity = service.selectById(id);
    	CasePaymentVO vo = BeanMapper.map(entity, CasePaymentVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<CasePaymentVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (CasePaymentVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(CasePaymentVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<CasePaymentVO>> queryList(@RequestBody QueryParam param) {


        IPage<CasePaymentEntity> page = service.queryPage(param,false);
        IPage<CasePaymentVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), CasePaymentVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<CasePaymentEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("CasePayment-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refCasePaymentData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CasePaymentVO>> refCasePaymentData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<CasePaymentEntity> page = service.queryPage(param,false);
        IPage<CasePaymentVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), CasePaymentVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * 根据caseId查询案件付款登记信息
     * @param caseId
     * @return
     */
    @RequestMapping(value = "/queryByCaseId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CasePaymentVO> queryByCaseId(@RequestParam Long caseId) {

        CasePaymentEntity entity = service.getOne(Wrappers.<CasePaymentEntity>lambdaQuery().eq(CasePaymentEntity::getCaseId,caseId));
        if(entity != null){
            CasePaymentVO vo = BeanMapper.map(entity, CasePaymentVO.class);
            return CommonResponse.success("查询详情数据成功！",vo);
        } else {
            return CommonResponse.error("无此条数据！");
        }

    }
}

==> ejc-law-impl-3.0.0-20221108.082218-21-sources.jar: com/ejianc/business/law/controller/CasePaymentController.java <==
package com.ejianc.business.law.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.law.bean.*;
import com.ejianc.business.law.service.ILedgerService;
import com.ejianc.business.law.service.impl.CasePaymentZiBpmServiceImpl;
import com.ejianc.business.law.service.impl.CasePaymentZiServiceImpl;
import com.ejianc.business.law.service.impl.CaseRegisteServiceImpl;
import com.ejianc.business.law.vo.CasePaymentZiVO;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.math.BigDecimal;
import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.law.service.ICasePaymentService;
import com.ejianc.business.law.vo.CasePaymentVO;

/**
 * 案件付款情况登记表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("casePayment")
public class CasePaymentController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String BILL_CODE = "Invoice_Open_Apply_Code";//此处需要根据实际修改

    @Autowired
    private ICasePaymentService service;

    @Autowired
    private SessionManager sessionManager;

    @Autowired
    private CaseRegisteServiceImpl registeService;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<CasePaymentVO> saveOrUpdate(@RequestBody CasePaymentVO saveOrUpdateVO) {
    	CasePaymentEntity entity = BeanMapper.map(saveOrUpdateVO, CasePaymentEntity.class);
        UserContext userContextCache =sessionManager.getUserContext();
        if(entity.getId() == null || entity.getId() == 0){
            //设置创建人姓名
            entity.setCreateUserName(userContextCache.getUserName());
            BillCodeParam billCodeParam = BillCodeParam.build(BILL_CODE,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }else {
            //设置修改人姓名
            entity.setUpdateUserName(userContextCache.getUserName());
        }
//        /**
//         * 更新主表中子表应付总金额和未付总金额
//         */
//        List<CasePaymentZiVO> ziVOList = saveOrUpdateVO.getCasePaymentZiList();
//        System.out.println(ziVOList);
//        //应付总金额
//        BigDecimal totalPayable = BigDecimal.ZERO;
//        //未付总金额
//        BigDecimal totalUnpaid = BigDecimal.ZERO;
//        for (CasePaymentZiVO ziVO : ziVOList) {
//            //子表应付金额
//            BigDecimal payable = ziVO.getAmountPayable();
//            //子表未付金额
//            BigDecimal unpaid = ziVO.getAmountUnpaid();
//            if(payable == null){
//                totalPayable = totalPayable.add(BigDecimal.ZERO);
//            } else {
//                totalPayable = totalPayable.add(payable);
//            }
//            if(unpaid == null){
//                totalUnpaid = totalUnpaid.add(BigDecimal.ZERO);
//            } else {
//                totalUnpaid = totalUnpaid.add(unpaid);
//            }
//        }
//    	entity.setTotalAmountPayable(totalPayable);
//        entity.setTotalAmountUnpaid(totalUnpaid);
//        /**
//         *结束
//         */
        service.saveOrUpdate(entity, false);
        ledgerSaveOrUpdate(entity);
        //更改支付状态
        registeService.update(Wrappers.<CaseRegisteEntity>lambdaUpdate()
                        .set(CaseRegisteEntity::getPayStateName,saveOrUpdateVO.getPayStateName())
                        .eq(CaseRegisteEntity::getId,saveOrUpdateVO.getCaseId()));
    	CasePaymentVO vo = BeanMapper.map(entity, CasePaymentVO.class);
    	return CommonResponse.success("保存或修改单据成功！",vo);
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CasePaymentVO> queryDetail(Long id) {
    	CasePaymentEntity entity = service.selectById(id);
    	CasePaymentVO vo = BeanMapper.map(entity, CasePaymentVO.class);
        return CommonResponse.success("查询详情数据成功！",vo);
    }


    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<CasePaymentVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (CasePaymentVO vo : vos) {
                // 参数是单据类型编码字符串 根据需求是否打开下面代码
                /* CommonResponse<String> resp = billTypeApi.checkQuote("billTypeCode", vo.getId());
                if(!resp.isSuccess()){
                    return CommonResponse.error("删除失败！"+resp.getMsg());
                }*/
            }
        }
        service.removeByIds(vos.stream().map(CasePaymentVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<CasePaymentVO>> queryList(@RequestBody QueryParam param) {


        IPage<CasePaymentEntity> page = service.queryPage(param,false);
        IPage<CasePaymentVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), CasePaymentVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<CasePaymentEntity> list = service.queryList(param);
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", list);
        ExcelExport.getInstance().export("CasePayment-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/refCasePaymentData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<CasePaymentVO>> refCasePaymentData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<CasePaymentEntity> page = service.queryPage(param,false);
        IPage<CasePaymentVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), CasePaymentVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }

    /**
     * 根据caseId查询案件付款登记信息
     * @param caseId
     * @return
     */
    @RequestMapping(value = "/queryByCaseId", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<CasePaymentVO> queryByCaseId(@RequestParam Long caseId) {

        CasePaymentEntity entity = service.getOne(Wrappers.<CasePaymentEntity>lambdaQuery().eq(CasePaymentEntity::getCaseId,caseId));
        if(entity != null){
            CasePaymentVO vo = BeanMapper.map(entity, CasePaymentVO.class);
            return CommonResponse.success("查询详情数据成功！",vo);
        } else {
            return CommonResponse.error("无此条数据！");
        }

    }

    /**
     * 案件台账关联更新
     */
    @Autowired
    private ILedgerService ledgerService;

    private void ledgerSaveOrUpdate(CasePaymentEntity entity){
        LedgerEntity ledgerEntity = ledgerService.getOne(Wrappers.<LedgerEntity>lambdaQuery().eq(LedgerEntity::getCaseId, entity.getId()));
        ledgerEntity.setPayState(entity.getPaymentState());//付款状态
        ledgerEntity.setPayStateName(entity.getPayStateName());
        ledgerService.saveOrUpdate(ledgerEntity);
    }
}
